import { Table, Select, Form, Button, Space, InputNumber, Modal, message } from 'antd';
import { useState, useEffect } from 'react';
import { api } from '@nice/client';

// 模拟接口调用函数
const addAgeRangeApi = async (start: number, end: number | null) => {
  // 这里替换为实际的接口调用
  console.log(`调用接口添加年龄范围: start=${start}, end=${end}`);
};

const addScoreStandardApi = async (score: number, standards: (number | null)[]) => {
  // 这里替换为实际的接口调用
  console.log(`调用接口添加分数标准: score=${score}, standards=${standards}`);
};

export default function AssessmentStandardPage() {
  const [form] = Form.useForm();
  const [standardForm] = Form.useForm();
  const [ageRanges, setAgeRanges] = useState<{ start: number; end: number | null; label: string; }[]>([]);
  const [dataSource, setDataSource] = useState<any[]>([]);
  const [loading, setLoading] = useState(false);
  // 新增状态控制模态框显示隐藏
  const [isModalVisible, setIsModalVisible] = useState(false); 
  // 新增状态存储年龄范围起始值
  const [startAge, setStartAge] = useState<number | null>(null); 
  // 新增状态存储年龄范围结束值
  const [endAge, setEndAge] = useState<number | null>(null); 

  // TRPC mutations
  // const createStandardMutation = api.sportStandard.createStandard.useMutation();
  // const updateStandardMutation = api.sportStandard.update.useMutation();
  // const standardsQuery = api.sportStandard.findMany.useQuery({
  //   include: {
  //     project: true
  //   }
  // });

  const columns = [
    {
      title: '分数',
      dataIndex: 'score',
      key: 'score',
      width: 100,
    },
    ...ageRanges.map((range, index) => ({
      title: range.label,
      dataIndex: `standard_${index}`,
      key: `standard_${index}`,
      render: (_: any, record: any) => (
        <InputNumber
          style={{ width: '100%' }}
          value={record[`standard_${index}`]}
          onChange={(value) => handleStandardChange(record.score, index, value)}
        />
      ),
    })),
  ];

  const handleStandardChange = (score: number, ageIndex: number, value: number | null) => {
    const newDataSource = dataSource.map(item => {
      if (item.score === score) {
        return {
          ...item,
          [`standard_${ageIndex}`]: value
        };
      }
      return item;
    });
    setDataSource(newDataSource);
  };

  const handleAddAgeRange = () => {
    // 点击按钮显示模态框
    setIsModalVisible(true); 
  };

  const handleOk = async () => {
    if (startAge === null) {
      message.error('请输入起始年龄');
      return;
    }
    try {
      // 调用模拟接口
      await addAgeRangeApi(startAge, endAge); 
      const newRange = {
        start: startAge,
        end: endAge,
        label: endAge ? `${startAge}-${endAge}岁` : `${startAge}岁以上`
      };
      setAgeRanges([...ageRanges, newRange]);
      setIsModalVisible(false);
      message.success('年龄范围添加成功');
    } catch (error) {
      console.error('添加年龄范围失败:', error);
      message.error('添加年龄范围失败');
    }
  };

  const handleCancel = () => {
    // 关闭模态框
    setIsModalVisible(false); 
  };

  const handleSave = async () => {
    try {
      const values = await form.validateFields();
      const { projectId, gender, personType, ageRanges} = values;

      // 将表格数据转换为后端需要的格式
      const scoreTable: Record<string, number[]> = {};
      dataSource.forEach(row => {
        const standards = ageRanges?.map((_, index) => row[`standard_${index}`]);
        scoreTable[row.score] = standards;
      });


      setLoading(true);
      await api.sportStandard.createStandard.useMutation().mutateAsync({
        data: {
          projectId,
          gender,
          personType,
          ageRanges: ageRanges.map(range => ({
            start: range.start,
            end: range.end,
            label: range.label
          })),
          scoreTable
        } 
      });
      message.success('保存成功');
    } catch (error) {
      console.error('保存失败:', error);
      message.error('保存失败');
    } finally {
      setLoading(false);
    }
  };

  useEffect(() => {
    // 初始化表格数据
    const initialData = [
      { score: 100, standard_0: null, standard_1: null, standard_2: null, standard_3: null },
      { score: 90, standard_0: null, standard_1: null, standard_2: null, standard_3: null },
    ];
    setDataSource(initialData);
  }, []);

  return (
    <div className="p-6">
      <h1 className="text-2xl font-bold mb-6">考核标准管理</h1>
      
      <Form form={form} layout="vertical">
        <Space size="large" className="mb-6">
          <Form.Item 
            label="项目" 
            name="projectId"
            rules={[{ required: true, message: '请选择考核项目' }]}
          >
            <Select
              style={{ width: 200 }}
              placeholder="选择考核项目"
              options={[
                { value: '1', label: '引体向上' },
                { value: '2', label: '3000米跑' },
              ]}
            />
          </Form.Item>

          <Form.Item 
            label="性别" 
            name="gender"
            rules={[{ required: true, message: '请选择性别' }]}
          >
            <Select
              style={{ width: 120 }}
              placeholder="选择性别"
              options={[
                { value: true, label: '男' },
                { value: false, label: '女' },
              ]}
            />
          </Form.Item>

          <Form.Item 
            label="人员类型" 
            name="personType"
            rules={[{ required: true, message: '请选择人员类型' }]}
          >
            <Select
              style={{ width: 160 }}
              placeholder="选择人员类型"
              options={[
                { value: 'officer', label: '警员' },
                { value: 'civilian', label: '职工' },
              ]}
            />
          </Form.Item>

          <Form.Item label="添加年龄范围" name="ageRanges">
            <Button type="primary" onClick={handleAddAgeRange}>
              添加年龄范围
            </Button>
          </Form.Item>
        </Space>

        <Table
          columns={columns}
          dataSource={dataSource}
          bordered
          pagination={false}
          scroll={{ x: 'max-content' }}
          loading={loading}
          rowKey="score"
        />

        <div className="mt-6">
          <Button type="primary" onClick={handleSave} loading={loading}>
            保存标准
          </Button>
        </div>
      </Form>

      {/* 模态框组件 */}
      <Modal
        title="添加年龄范围"
        visible={isModalVisible}
        onOk={handleOk}
        onCancel={handleCancel}
      >
        <Form.Item label="起始年龄" required>
          <InputNumber
            value={startAge}
            onChange={(value) => setStartAge(value)}
          />
        </Form.Item>
        <Form.Item label="结束年龄">
          <InputNumber
            value={endAge}
            onChange={(value) => setEndAge(value)}
          />
        </Form.Item>
      </Modal>
    </div>
  );
}
